@@ -3,6 +3,11 @@
 #Could make bounce effect when hit boundaries by sending in opposite direction for count down moment
 #could make accelrate faster by using previuos x,y as well as start x,y as startx,y means you cant accelerate until back to starting point.
 
+#               Save level high score scored at
+#               Increase fps from 60 to 30
+#               Change max_accel based on level no
+#               Change rate of effect of the toys
+#17.05.10    Slow snapy down at startup
 #15.05.10    copy snapy.dat.reset with write permissions if not already found. Avoids file overwrite if installing new version
 #13.05.10    Fixed all paths to point to opt/snapy instead of opt root
 #               Increase speed per level
@@ -32,15 +37,18 @@ DEBUG_ON_DIE = 0
 debug_xy = 0
 
 #Consts
-speed=.25          #Speed can be float and move will occur in integers
+fps=30
+unit_speed=.25
+speed=.5          #Speed can be float and move will occur in integers
 level_speed = speed
-smooth=20       #Rate of change in accelerometer before a speed/direction change is registered
+smooth=10       #Rate of change in accelerometer before a speed/direction change is registered
 accel_div=12
-max_accel=25
+max_accel=2
 map_accel = 1
 accel_x=0
 accel_y=0
 accel_delay = 0
+toy_slow_rate = 5
 screen_x = 800
 screen_y = 440
 food_size = 20
@@ -53,6 +61,7 @@ toy_char = "T"
 bumper_size = 8  #No of pixals around outside  of snapy where can't crash
 immortal_period = 20
 
+
 #Globals
 ax = 0
 ay = 0
@@ -86,6 +95,9 @@ high_score3 = 0
 high_score_name = ""
 high_score2_name = ""
 high_score3_name = ""
+high_score_l1 = 0
+high_score_l2 = 0
+high_score_l3 = 0
 new_high_king = ""
 current_high_king = ""
 new_high_score = 0
@@ -128,7 +140,7 @@ def get_rotation():
         global down
         global cx, cy, cz
         global accel_div, max_accel, accel_x, accel_y,  accel_delay, speed
-        global trip_switchx , trip_switchy , trip_value
+        global trip_switchx , trip_switchy , trip_value,  unit_speed
         
         old_ax=ax
         old_ay=ay
@@ -163,9 +175,9 @@ def get_rotation():
 
             
         if new_accel_x > accel_x:
-                accel_x = accel_x + .25
+                accel_x = accel_x + unit_speed
         elif new_accel_x < accel_x:
-                accel_x = accel_x - .25                
+                accel_x = accel_x - unit_speed                
         if accel_x > max_accel:
             accel_x = max_accel
 
@@ -184,9 +196,9 @@ def get_rotation():
 
             
         if new_accel_y > accel_y:
-                accel_y = accel_y + .25                 
+                accel_y = accel_y + unit_speed         
         elif new_accel_y < accel_y:
-                accel_y = accel_y - .25
+                accel_y = accel_y - unit_speed
         if accel_y > max_accel:
             accel_y = max_accel
 
@@ -306,11 +318,12 @@ def  write_file():
 def save_game_settings():
     try:
         global score,  high_score, high_score2 , high_score3 , high_score_name , high_score2_name , high_score3_name,  new_high_king
-        global current_high_king,  new_high_score
+        global current_high_king,  new_high_score, high_score_l1,  high_score_l2,  high_score_l3
+        global food_no
         
         position = 0
-        
-        print "starting high score saving..."
+        level_no = food_no + 1
+        print "starting high score saving...l#" + str(level_no)
         
         #Save top 3 high scores
         if score > high_score:
@@ -318,9 +331,12 @@ def save_game_settings():
      
             high_score3_name = high_score2_name
             high_score3 = high_score2
+            high_score_l3 = high_score_l2
             high_score2_name = high_score_name
             high_score2 = high_score
+            high_score_l2 = high_score_l1
             high_score = score
+            high_score_l1 = (level_no)
             
             pet_name()
             high_score_name = new_high_king
@@ -329,7 +345,9 @@ def save_game_settings():
         elif score > high_score2:
             high_score3_name = high_score2_name
             high_score3 = high_score2
+            high_score_l3 = high_score_l2
             high_score2 = score
+            high_score_l2 = (level_no)
             
             position = 2
             pet_name()
@@ -338,6 +356,7 @@ def save_game_settings():
             
         elif score > high_score3:
             high_score3 = score
+            high_score_l3 = (level_no)
             position = 3
             pet_name()
             high_score3_name = new_high_king
@@ -353,6 +372,9 @@ def save_game_settings():
             file.write("HighKing1: " + high_score_name + "\n")
             file.write("HighKing2: " + high_score2_name + "\n")
             file.write("HighKing3: " + high_score3_name + "\n")
+            file.write("Highl1: " + str(high_score_l1) + "\n")
+            file.write("Highl2: " + str(high_score_l2)+ "\n")
+            file.write("Highl3: " + str(high_score_l3) + "\n")
             
             file.close() 
         
@@ -364,6 +386,7 @@ def save_game_settings():
         
 def load_game_settings():
     global score,  high_score, high_score2 , high_score3 , high_score_name , high_score2_name , high_score3_name,  new_high_king
+    global high_score_l1, high_score_l2, high_score_l3
     
     #Just saves high score
     print "reading game data from disk..."
@@ -412,8 +435,28 @@ def load_game_settings():
             high_score3_name = "Hisss..."
         else:
             high_score3_name = buffer[len("HighKing3: "):].strip()
-        
-      
+
+        try:
+            buffer = file.readline()
+            if buffer == "":
+                high_score_l1 = 3
+            else:
+                high_score_l1 = int(buffer[len("Highl1: "):].strip())
+            buffer = file.readline()
+            if buffer == "":
+                high_score_l2 = 2
+            else:
+                high_score_l2 = int(buffer[len("Highl2: "):].strip())
+            buffer = file.readline()
+            if buffer == "":
+                high_score_l3 = 1
+            else:
+                high_score_l3 = int(buffer[len("Highl3: "):].strip())
+
+        except:
+            #May not have levels if old version of file
+            print "old settings version"
+            
         file.close() 
     except:
         print "error loading high score with file..."
@@ -527,6 +570,7 @@ def display_death_note():
     
     global score,  high_score, high_score2 , high_score3 , high_score_name , high_score2_name , high_score3_name,  new_high_king 
     global death_yoink,  death_high,  new_high_score,  red,  blue,  green,  redup,  blueup,  greenup
+    global high_score_l1, high_score_l2, high_score_l3
     
     #print "death notes jim..."
     
@@ -599,9 +643,9 @@ def display_death_note():
     
     font = pygame.font.Font(None, king_size)
     # Render the text
-    text2 = font.render('1st King ' + high_score_name + ' : ' + str(high_score) , True, (red,0, 0),king_back)
-    text3 = font.render('2nd Sir '+ high_score2_name + ' : ' + str(high_score2) , True, (0,green, 0), king_back)
-    text4 = font.render('3rd Sad ' + high_score3_name + ' : ' + str(high_score3) , True, (0,0, blue), king_back)
+    text2 = font.render('1st King ' + high_score_name + ' : ' + str(high_score)  + " (@" + str(high_score_l1) + ")", True, (red,0, 0),king_back)
+    text3 = font.render('2nd Sir '+ high_score2_name + ' : ' + str(high_score2) + " (@" + str(high_score_l2) + ")", True, (0,green, 0), king_back)
+    text4 = font.render('3rd Sad ' + high_score3_name + ' : ' + str(high_score3) + " (@" + str(high_score_l3) + ")",True, (0,0, blue), king_back)
 
 
     # Create a rectangle
@@ -694,7 +738,7 @@ def eat_or_die():
     global food_x, food_y, food_score, food_no, food_char, x, y, food_size, map,  left, right,  speed, accel_x,  accel_y, DEBUG_ON_DIE
     global bumper_size ,  death_detail, snapy_size,  snapy_char,  map_accel, immortal, immortal_period,  bg_channel
     global toy_char,  toy_size,  toy_x,  toy_y,  toys,  blank_snapy,  score,  high_score,  snapy_length,  time_score
-    global high_score3,  level_score,  level_speed
+    global high_score3,  level_score,  level_speed, unit_speed, max_accel,  toy_slow_rate
     
     count = y + 31
     happy_meal = 0
@@ -728,10 +772,16 @@ def eat_or_die():
             count = count -1
     if toy_time == 1:
         #Toy resets speed to slowest
-        level_speed = level_speed - (.25 * 3)
-        if level_speed < .25:
-            level_speed = .25
+        level_speed = level_speed - (unit_speed * toy_slow_rate)
+        if level_speed < unit_speed + int(food_no / 5):
+            level_speed = unit_speed + int(food_no / 5)
         speed = level_speed
+        accel_x = 0
+        accel_y = 0
+        max_accel = max_accel - 1
+        if max_accel < (2 +  int(food_no / 5)):
+            max_accel = (2 +  int(food_no / 5))
+        
         toys = 0
         vibrate_small()
         #sfx_rnd = random.randint(1, 5)
@@ -798,8 +848,12 @@ def eat_or_die():
             time_score = 0
             snapy_length = 0
             level_score = 0
-            food_no = 0
-            speed = .25
+            speed = .5
+            max_accel = unit_speed * 2
+            if max_accel < 2:
+                max_accel = 2
+            accel_x = 0
+            accel_y = 0
             level_speed = speed
             #Clear screen
             white = 255, 255, 255
@@ -814,7 +868,8 @@ def eat_or_die():
             if score >= high_score3:
                 save_game_settings()
             bg_bright = 255
-            
+            #Need to keep this until high score is saved
+            food_no = 0
             #DEATH LOOP until restart
             #display_death_note()
             death_march()
@@ -861,7 +916,8 @@ def eat_or_die():
 
             #Speed in increases 1 per level
             speed = level_speed
-            level_speed = level_speed + .25
+            level_speed = level_speed + unit_speed
+            max_accel = max_accel + unit_speed
             #reset acceleration
             accel_x = 0
             accel_y = 0
@@ -881,7 +937,7 @@ def eat_or_die():
         rnd_no = random.randint(1, 4)
         food = pygame.image.load("/home/opt/snapy/images/food" + str(rnd_no) + ".jpg").convert()
         screen.blit(food, (food_x,food_y))
-        if speed > (.25 * 8):
+        if speed > (unit_speed * 8):
             if rnd_no < 2:
                 #Create a toy
                 toys = 1
@@ -964,7 +1020,7 @@ clock = pygame.time.Clock()
 while 1:
 
     # Make sure game doesn't run at more than 60 frames per second
-    clock.tick(60)
+    clock.tick(fps)
 
     #Turn on backlight
     if light_on <= 0:
@@ -1046,7 +1102,7 @@ while 1:
             dis_hi = high_score
             if score > high_score:
                 dis_hi = score
-            pygame.display.set_caption ("Snapy!! S:" + str(score) + " H:" + str(dis_hi) + " L:" + str(food_no)  + " Sp:" + str(speed))
+            pygame.display.set_caption ("Snapy!! S:" + str(score) + " H:" + str(dis_hi) + " L:" + str(food_no + 1)  + " Sp:" + str(int(speed)) )
 
 
         #button1rect = button1.get_rect()
